import type { Frame, Future, Operation, Scope } from "../types.js";
/**
 * Get the scope of the currently running {@link Operation}.
 *
 * @returns an operation yielding the current scope
 */
export declare function useScope(): Operation<Scope>;
/**
 * Create a new scope to serve as an entry point from normal
 * JavaScript execution into Effection.
 *
 * When creating a fresh scope (as opposed to capturing a reference to
 * an existing one via {@link useScope}) it is the responsibility of
 * the creator of the new scope to destroy it when it is no longer needed.
 *
 * @example
 * ```js
 * let [scope, destroy] = createScope();
 * let task = scope.run(function*() {
 *   //do some long running work
 * });
 *
 * //... later
 * await destroy();
 *
 * ```
 * @returns a tuple containing the new scope, and a function to destroy it.
 */
export declare function createScope(frame?: Frame): [Scope, () => Future<void>];
