"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createContext = void 0;
const create_js_1 = require("./run/create.js");
const scope_js_1 = require("./run/scope.js");
function createContext(key, defaultValue) {
    let context = (0, create_js_1.create)(`Context`, { key }, {
        defaultValue,
        *get() {
            let scope = yield* (0, scope_js_1.useScope)();
            return scope.get(context);
        },
        *set(value) {
            let scope = yield* (0, scope_js_1.useScope)();
            return scope.set(context, value);
        },
        *[Symbol.iterator]() {
            let value = yield* context.get();
            if (typeof value === "undefined") {
                throw new MissingContextError(`missing required context: '${key}'`);
            }
            else {
                return value;
            }
        },
    });
    return context;
}
exports.createContext = createContext;
class MissingContextError extends Error {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "name", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: "MissingContextError"
        });
    }
}
//# sourceMappingURL=context.js.map