"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.lift = void 0;
/**
 * Convert a simple function into an {@link Operation}
 *
 * @example
 * ```js
 * let log = lift((message) => console.log(message));
 *
 * export function* run() {
 *   yield* log("hello world");
 *   yield* log("done");
 * }
 * ```
 *
 * @returns a function returning an operation that invokes `fn` when evaluated
 */
function lift(fn) {
    return (...args) => {
        return ({
            [Symbol.iterator]() {
                let value = fn(...args);
                return { next: () => ({ done: true, value }) };
            },
        });
    };
}
exports.lift = lift;
//# sourceMappingURL=lift.js.map