"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sleep = void 0;
const instructions_js_1 = require("./instructions.js");
/**
 * Sleep for the given amount of milliseconds.
 *
 * @example
 * ```typescript
 * import { main, sleep } from 'effection';
 *
 * await main(function*() {
 *   yield sleep(2000);
 *   console.log("Hello lazy world!");
 * });
 * ```
 *
 * @param duration - the number of milliseconds to sleep
 */
function sleep(duration) {
    return (0, instructions_js_1.action)(function* sleep(resolve) {
        let timeoutId = setTimeout(resolve, duration);
        try {
            yield* (0, instructions_js_1.suspend)();
        }
        finally {
            clearTimeout(timeoutId);
        }
    });
}
exports.sleep = sleep;
//# sourceMappingURL=sleep.js.map